import { STSClient, GetCallerIdentityCommandOutput } from "@aws-sdk/client-sts";
export declare class AWSAccount {
    /**
     * @internal
     */
    static _sts: STSClient;
    /**
     * @internal
     */
    static _callerIdentity?: GetCallerIdentityCommandOutput;
    /**
     * Retrieves the caller identity response using the AWS SDK client for
     * Security Token Service (STS). If the caller identity response is not
     * cached, it fetches the response and stores it for subsequent calls.
     *
     * @returns {Promise<GetCallerIdentityCommandOutput>} A promise resolving to
     * @internal
     * the caller identity response.
     */
    static _getCallerIdentityResponse(): Promise<GetCallerIdentityCommandOutput>;
    /**
     * Retrieves the AWS Account ID associated with the current AWS credentials
     * or environment. If available, it uses the environment variable
     * `AWS_ACCOUNT_ID`. Otherwise, it fetches the AWS Account ID from the caller
     * identity response obtained via STS.
     *
     * @returns {Promise<string | undefined>} A promise that resolves to the
     * AWS Account ID as a string.
     * @throws {Error} If the AWS Account ID cannot be resolved.
     */
    static awsAccountId(): Promise<string>;
    /**
     * Retrieves the AWS region associated with the current AWS credentials
     * or environment. If available, it uses the environment variable
     * `AWS_DEFAULT_REGION`. Otherwise, it fetches the AWS region from the caller
     * identity response obtained via STS.
     *
     * @returns {Promise<string | undefined>} A promise that resolves to the
     * AWS region as a string.
     * @throws {Error} If the AWS region cannot be resolved.
     */
    static awsRegion(): Promise<string>;
}
