import { IMirror, Mirror, MirrorProps } from "../git";
export interface MirrorToCodecommitProps {
    /**
     * The name of the target Codecommit repository.
     * @default CI_PROJECT_PATH_SLUG.
     */
    readonly repositoryName?: string;
    /**
     * The AWS region you want to operate in. When not set, it would be
     * curl'ed from the current EC2 instance metadata.
     */
    readonly awsRegion?: string;
    /**
     * Only if the ECR would be created on the first call, these AWS Tags
     * becomes applied to the AWS Codecommit resource. Changed values won't
     * change the tags on an already existing ECR. This string must have the
     * pattern: `Tag1=Value1,Tag2=Value2`
     */
    readonly infrastructureTags?: string;
    /**
     * Options for the upstream Mirror job.
     */
    readonly mirrorOpts?: MirrorProps;
}
export interface IMirrorToCodecommit extends IMirror {
    /**
     * The name of the target Codecommit repository.
     * @default CI_PROJECT_PATH_SLUG.
     */
    repositoryName: string;
    /**
     * The AWS region you want to operate in. When not set, it would be
     * curl'ed from the current EC2 instance metadata.
     */
    awsRegion?: string;
    /**
     * Only if the ECR would be created on the first call, these AWS Tags
     * becomes applied to the AWS Codecommit resource. Changed values won't
     * change the tags on an already existing ECR. This string must have the
     * pattern: `Tag1=Value1,Tag2=Value2`
     */
    infrastructureTags?: string;
}
/**
 * This job clones the CI_COMMIT_REF_NAME of the current repository and forcefully pushes this REF to a AWS CodeCommit repository.
 *
 * This job requires following IAM permissions:
 *
 * - codecommit:CreateRepository
 * - codecommit:GetRepository
 * - codecommit:CreateBranch
 * - codecommit:GitPush
 * - codecommit:TagResource
 *
 * You could also limit the resource to `!Sub arn:aws:codecommit:${AWS::Region}:${AWS::AccountId}:<repository-name>`.
 *
 */
export declare class MirrorToCodecommit extends Mirror implements IMirrorToCodecommit {
    repositoryName: string;
    awsRegion?: string;
    infrastructureTags?: string;
    mirrorOpts?: MirrorProps;
    constructor(props: MirrorToCodecommitProps);
    render(): any;
}
