#! /usr/bin/env node
import { CloudFormationClient } from "@aws-sdk/client-cloudformation";
import { Credentials } from "@aws-sdk/client-sts";
/**
 * Creates a CloudFormation client with the provided AWS credentials.
 * @param credentials - Optional. AWS credentials to use for authentication.
 * @returns A CloudFormationClient object.
 * @throws {Error} If the provided credentials are missing any required fields.
 */
export declare function getCloudFormationClient(credentials?: Credentials): CloudFormationClient;
/**
 * Checks if any of the specified CloudFormation stacks are still in progress.
 * @param cfnClient - The CloudFormationClient instance to use for API requests.
 * @param stackNames - An array of CloudFormation stack names to check.
 * @returns A boolean indicating whether any of the stacks are still in progress.
 */
export declare function cnfWaiter(cfnClient: CloudFormationClient, stackNames: string[]): Promise<boolean>;
/**
 * The main function that waits for CloudFormation stacks to complete their operations.
 * @returns void
 */
export declare function main(): Promise<void>;
