import { PipInstallRequirementsProps } from "./scripts";
import { Job } from "../job";
export interface BdistWheelProps {
    readonly jobName?: string;
    readonly jobStage?: string;
    readonly pipRequirements?: PipInstallRequirementsProps;
}
export interface IBdistWheel {
    readonly pipenvVersionSpecifier?: string;
    readonly requirementsFile?: string;
}
/**
 * Runs `python3 setup.py bdist_wheel` and installs project requirements
 * Requirements are installed by `LinuxScripts.pipInstallRequirements()`.
 *
 * This subclass of `Job` configures the following defaults for the superclass:
 * - name: bdist_wheel
 * - stage: build
 * - artifacts: Path 'dist/'
 *
 * Requires a `Pipfile.lock` or `requirements.txt` in your project folder
 * containing at least `setuptools`. Creates artifacts under the path 'dist/'.
 *
 * @param pipenvVersionSpecifier - The version hint of pipenv to install if
 * `Pipfile.lock` is found. For example '==2022.08.15'.
 * @default to an empty string, indicating
 * installation of the latest version.
 */
export declare class BdistWheel extends Job implements IBdistWheel {
    readonly pipenvVersionSpecifier?: string;
    readonly requirementsFile?: string;
    constructor(props: BdistWheelProps);
    render(): any;
}
