import { Job } from "../";
export interface Flake8Props {
    /**
     * The name of the job.
     */
    readonly jobName?: string;
    /**
     * The stage of the job.
     */
    readonly jobStage?: string;
}
export interface IFlake8 {
}
/**
 * Runs:
 *
 * ```
 * pip3 install --upgrade flake8
 * flake8
 * ```
 *
 * This subclass of `Job` configures the following defaults for the superclass:
 * - name: flake8
 * - stage: lint
 */
export declare class Flake8 extends Job implements IFlake8 {
    constructor(props: Flake8Props);
}
export interface MyPyProps {
    /**
     * The name of the job.
     */
    readonly jobName?: string;
    /**
     * The stage of the job.
     */
    readonly jobStage?: string;
    /**
     * If `mypy` is not already installed, this version will be installed.
     * Installs latest version if `undefined`.
     */
    readonly myPyVersion?: string;
    /**
     * Adds arguments to mypy execution.
     */
    readonly myPyOptions?: string;
    /**
     * Package directory to type check.
     */
    readonly packageDir: string;
}
export interface IMyPy {
    /**
     * If `mypy` is not already installed, this version will be installed.
     * Installs latest version if `undefined`.
     */
    myPyVersion?: string;
    /**
     * Adds arguments to mypy execution.
     */
    myPyOptions?: string;
    /**
     * Package directory to type check.
     */
    packageDir: string;
}
/**
 * Install mypy if not already installed.
 * Execute mypy for `packageDir`.
 *
 * This subclass of `Job` configures the following defaults for the superclass:
 * - name: mypy
 * - stage: lint
 *
 * @returns {Job} - The configured `gcip.Job` instance.
 */
export declare class MyPy extends Job implements IMyPy {
    myPyVersion?: string;
    myPyOptions?: string;
    packageDir: string;
    constructor(props: MyPyProps);
    render(): any;
}
export interface IsortProps {
    /**
     * The name of the job.
     */
    readonly jobName?: string;
    /**
     * The stage of the job.
     */
    readonly jobStage?: string;
}
export interface IIsort {
}
/**
 * Runs:
 *
 * ```
 * pip3 install --upgrade isort
 * isort --check .
 * ```
 *
 * This subclass of `Job` will configure following defaults for the superclass:
 *
 * - name: isort
 * - stage: lint
 */
export declare class Isort extends Job implements IIsort {
    constructor(props: IsortProps);
}
